import os
from typing import Annotated
import logging

from pydantic import BaseModel
from pydantic_yaml import parse_yaml_file_as
from fastapi import Depends


class _ComponentConfig(BaseModel):
    # The JID of the component
    jid: str

    # Address of server's component port
    server: str

    # The component's secret.
    secret: str


class _Config(BaseModel):
    # DB URI for sqlmodel
    database: str

    # Component configuration
    component: _ComponentConfig


log = logging.getLogger("config")


def load_config() -> _Config:
    """
    Load the application config
    """

    config_path = "/etc/xmpp-api/config.yaml"
    if (env_config_file := os.environ.get("XMPP_API__CONFIG_FILE")) is not None:
        config_path = env_config_file

    log.info(f"Reading configuration from {config_path}")
    with open(config_path, "r", encoding="utf8") as f:
        return parse_yaml_file_as(_Config, f)


ConfigDep = Annotated[_Config, Depends(load_config)]
